@@ -35,13 +35,13 @@ import sipconfig
 # These are installation specific values created when PyQt4 was configured.
 _pkg_config = {
     'pyqt_bin_dir':      '/usr/bin',
-    'pyqt_config_args':  '-w --confirm-license --no-designer-plugin',
+    'pyqt_config_args':  '-w --confirm-license --no-designer-plugin --no-docstrings LIBS_OPENGL=-lGLESv2 -lEGL',
     'pyqt_mod_dir':      '/usr/lib/python2.5/site-packages/PyQt4',
     'pyqt_modules':      'QtCore QtGui QtMaemo5 QtMultimedia QtNetwork QtOpenGL QtScript QtScriptTools QtSql QtSvg QtTest QtWebKit QtXml QtXmlPatterns phonon',
     'pyqt_sip_dir':      '/usr/share/sip/PyQt4',
-    'pyqt_sip_flags':    '-x VendorID -t WS_X11 -x PyQt_NoPrintRangeBug -t Qt_4_6_2 -x Py_v3 -g',
-    'pyqt_version':      0x040704,
-    'pyqt_version_str':  'snapshot-4.7.4-4e4296742920',
+    'pyqt_sip_flags':    '-x VendorID -t WS_X11 -x PyQt_NoPrintRangeBug -x PyQt_NoOpenGLES -x PyQt_qreal_double -t Qt_4_6_2 -x Py_v3 -g',
+    'pyqt_version':      0x040705,
+    'pyqt_version_str':  'snapshot-4.7.5-7088e9094087',
     'qt_data_dir':       '/usr/share/qt4',
     'qt_dir':            '/usr',
     'qt_edition':        'free',
@@ -66,7 +66,7 @@ _default_macros = {
     'CFLAGS_MT_DBG':            '',
     'CFLAGS_MT_DLL':            '',
     'CFLAGS_MT_DLLDBG':         '',
-    'CFLAGS_RELEASE':           '-O2',
+    'CFLAGS_RELEASE':           '-O3 -fno-omit-frame-pointer -fno-optimize-sibling-calls',
     'CFLAGS_RTTI_OFF':          '',
     'CFLAGS_RTTI_ON':           '',
     'CFLAGS_SHLIB':             '-fPIC',
@@ -88,7 +88,7 @@ _default_macros = {
     'CXXFLAGS_MT_DBG':          '',
     'CXXFLAGS_MT_DLL':          '',
     'CXXFLAGS_MT_DLLDBG':       '',
-    'CXXFLAGS_RELEASE':         '-O2',
+    'CXXFLAGS_RELEASE':         '-O3 -fno-omit-frame-pointer -fno-optimize-sibling-calls',
     'CXXFLAGS_RTTI_OFF':        '',
     'CXXFLAGS_RTTI_ON':         '',
     'CXXFLAGS_SHLIB':           '-fPIC',
@@ -97,7 +97,7 @@ _default_macros = {
     'CXXFLAGS_THREAD':          '-D_REENTRANT',
     'CXXFLAGS_WARN_OFF':        '-w',
     'CXXFLAGS_WARN_ON':         '-Wall -W',
-    'DEFINES':                  '',
+    'DEFINES':                  'QT_GL_NO_SCISSOR_TEST QT_DEFAULT_TEXTURE_GLYPH_CACHE_WIDTH=1024',
     'DEL_FILE':                 'rm -f',
     'EXTENSION_PLUGIN':         '',
     'EXTENSION_SHLIB':          '',
@@ -105,14 +105,14 @@ _default_macros = {
     'INCDIR_OPENGL':            '/usr/X11R6/include',
     'INCDIR_QT':                '/usr/include',
     'INCDIR_X11':               '/usr/X11R6/include',
-    'LFLAGS':                   '',
+    'LFLAGS':                   '-Wl,-rpath-link,/usr/lib',
     'LFLAGS_CONSOLE':           '',
     'LFLAGS_CONSOLE_DLL':       '',
     'LFLAGS_DEBUG':             '',
     'LFLAGS_DLL':               '',
     'LFLAGS_OPENGL':            '',
     'LFLAGS_PLUGIN':            '-shared',
-    'LFLAGS_RELEASE':           '-Wl,-O1',
+    'LFLAGS_RELEASE':           '-Wl,-O1 -Wl,--hash-style=gnu',
     'LFLAGS_SHLIB':             '-shared',
     'LFLAGS_SONAME':            '-Wl,-soname,',
     'LFLAGS_THREAD':            '',
@@ -128,10 +128,11 @@ _default_macros = {
     'LIBS_CORE':                '',
     'LIBS_GUI':                 '',
     'LIBS_NETWORK':             '',
-    'LIBS_OPENGL':              '-lGLU -lGL',
+    'LIBS_OPENGL':              '-lGLESv2 -lEGL',
     'LIBS_RT':                  '',
     'LIBS_RTMT':                '',
     'LIBS_THREAD':              '-lpthread',
+    'LIBS_WEBKIT':              '',
     'LIBS_WINDOWS':             '',
     'LIBS_X11':                 '-lXext -lX11 -lm',
     'LINK':                     'g++',
